==> jc-1.4.0.tar.gz: polyglot/ext/jl/ast/NodeFactory__5fc__242.h <==
// class polyglot.ext.jl.ast.NodeFactory_c$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2917835e17447a08 polyglot_ext_jl_ast_AbstractDelFactory__5fc
// @dep_class 56f6e0137a406 polyglot_ext_jl_ast_NodeFactory__5fc__242

// header file dependencies
// @dep_header polyglot_ext_jl_ast_AbstractDelFactory__5fc

#include "polyglot/ext/jl/ast/AbstractDelFactory__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_NodeFactory__5fc__242_H_
#define _JC_polyglot_ext_jl_ast_NodeFactory__5fc__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_refs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_nonrefs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$refs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$refs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$nonrefs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$object	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$object;

typedef const struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vmethods	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtable	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtype	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$object *);

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vmethods {
};

// Vtable
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_AbstractDelFactory__5fc$vmethods	polyglot_ext_jl_ast_AbstractDelFactory__5fc;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vmethods	polyglot_ext_jl_ast_NodeFactory__5fc__242;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$refs {
    _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_refs	polyglot_ext_jl_ast_NodeFactory__5fc__242;
    _jc_polyglot_ext_jl_ast_AbstractDelFactory__5fc$sub_refs	polyglot_ext_jl_ast_AbstractDelFactory__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_AbstractDelFactory__5fc$sub_nonrefs	polyglot_ext_jl_ast_AbstractDelFactory__5fc;
    _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_nonrefs	polyglot_ext_jl_ast_NodeFactory__5fc__242;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$object {
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtype _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_NodeFactory__5fc__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_NodeFactory__5fc__242_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/ast/NodeFactory__5fc__242.h <==
// class polyglot.ext.jl.ast.NodeFactory_c$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2917835e17447a08 polyglot_ext_jl_ast_AbstractDelFactory__5fc
// @dep_class 56f6e0137a406 polyglot_ext_jl_ast_NodeFactory__5fc__242

// header file dependencies
// @dep_header polyglot_ext_jl_ast_AbstractDelFactory__5fc

#include "polyglot/ext/jl/ast/AbstractDelFactory__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_NodeFactory__5fc__242_H_
#define _JC_polyglot_ext_jl_ast_NodeFactory__5fc__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_refs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_nonrefs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$refs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$refs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$nonrefs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$object	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$object;

typedef const struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vmethods	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtable	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtype	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vmethods {
};

// Vtable
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_AbstractDelFactory__5fc$vmethods	polyglot_ext_jl_ast_AbstractDelFactory__5fc;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vmethods	polyglot_ext_jl_ast_NodeFactory__5fc__242;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$refs {
    _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_refs	polyglot_ext_jl_ast_NodeFactory__5fc__242;
    _jc_polyglot_ext_jl_ast_AbstractDelFactory__5fc$sub_refs	polyglot_ext_jl_ast_AbstractDelFactory__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_AbstractDelFactory__5fc$sub_nonrefs	polyglot_ext_jl_ast_AbstractDelFactory__5fc;
    _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$sub_nonrefs	polyglot_ext_jl_ast_NodeFactory__5fc__242;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$object {
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$vtype _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_NodeFactory__5fc__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_NodeFactory__5fc__242$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_NodeFactory__5fc__242_H_ */
